import os
import sys
import tempfile
from subprocess import check_call


#########
# HELPERS
#########


def create_setup_py(package_name: str, author: str, author_email: str) -> str:
    return f"""
from setuptools import setup

setup(
    name='{package_name}',
    description='{package_name}',
    version='0.0.1',
    author={author},
    author_email={author_email}
)
"""


def create_package(package_name: str, author: str, author_email: str) -> str:
    # Create a temporary directory for the package
    temp_dir = tempfile.mkdtemp()
    package_dir = os.path.join(temp_dir, package_name)

    # Create package structure
    os.makedirs(package_dir)
    with open(os.path.join(package_dir, "__init__.py"), "w") as f:
        pass  # Empty file

    # Create setup.py
    with open(os.path.join(temp_dir, "setup.py"), "w") as f:
        f.write(create_setup_py(package_name, author, author_email))

    # Build the package
    check_call([sys.executable, "setup.py", "sdist"], cwd=temp_dir)

    return temp_dir


def upload_package(package_dir: str):
    check_call(["twine", "upload", "dist/*"], cwd=package_dir)


######
# MAIN
######


def claim_pypi_package(package_name: str):
    package_dir = create_package(package_name)
    upload_package(package_dir)



import os
import tempfile
from subprocess import check_call


#########
# HELPERS
#########


def create_package_json(package_name: str, author: str, author_email: str) -> str:
    return f"""
{{
  "name": "{package_name}",
  "version": "0.0.1",
  "description": "A placeholder package to claim the name {package_name}",
  "main": "index.js",
  "author": "{author} <{author_email}>",
  "license": "ISC"
}}
"""


def create_package(package_name: str, author: str, author_email: str) -> str:
    # Create a temporary directory for the package
    temp_dir = tempfile.mkdtemp()
    package_dir = os.path.join(temp_dir, package_name)

    # Create package structure
    os.makedirs(package_dir)
    with open(os.path.join(package_dir, "index.js"), "w") as f:
        pass  # Empty file

    # Create package.json
    with open(os.path.join(package_dir, "package.json"), "w") as f:
        f.write(create_package_json(package_name, author, author_email))

    return package_dir


def upload_package(package_dir: str):
    check_call(["npm", "publish"], cwd=package_dir)


######
# MAIN
######


def claim_npm_package(package_name: str, author: str, author_name: str):
    package_dir = create_package(package_name, author, author_name)
    upload_package(package_dir)



# Standard library
import sys
import argparse
from subprocess import check_output

# Local
from colonizer.pypi import claim_pypi_package
from colonizer.npm import claim_npm_package


#########
# HELPERS
#########


def get_author() -> str:
    return check_output(["git", "config", "user.name"], encoding="utf-8").strip()


def get_author_email() -> str:
    return check_output(["git", "config", "user.email"], encoding="utf-8").strip()


######
# MAIN
######


def main():
    parser = argparse.ArgumentParser(description="Claim a package name on PyPI or npm.")
    parser.add_argument(
        "--pypi", type=str, help="The name of the package to claim on PyPI"
    )
    parser.add_argument(
        "--npm", type=str, help="The name of the package to claim on npm"
    )
    parser.add_argument(
        "--author",
        type=str,
        default=None,
        required=False,
        help="The author of the package",
    )
    parser.add_argument(
        "--author-email",
        type=str,
        default=None,
        required=False,
        help="The author email of the package",
    )

    args = parser.parse_args()
    author = args.author if args.author else get_author()
    author_email = args.author_email if args.author_email else get_author_email()

    if args.pypi:
        claim_pypi_package(args.pypi, author, author_email)
    elif args.npm:
        claim_npm_package(args.npm, author, author_email)
    else:
        print(
            "Please specify either --pypi or --npm with a package name. And optionally --author and --author-email."
        )
        sys.exit(1)



try:
    from setuptools import setup
except ImportError:
    from distutils.core import setup
from codecs import open
import sys

if sys.version_info[:3] < (3, 0, 0):
    sys.stdout.write("Requires Python 3 to run.")
    sys.exit(1)

with open("README.md", encoding="utf-8") as file:
    readme = file.read()

setup(
    name="colonizer",
    version="1.0.1",
    description="A terrible tool for bad people",
    url="https://github.com/shobrook/colonizer",
    author="shobrook",
    author_email="shobrookj@gmail.com",
    keywords="pypi npm node python package reserve template project generator",
    include_package_data=True,
    packages=["colonizer"],
    entry_points={"console_scripts": ["colonizer = colonizer.colonizer:main"]},
    # install_requires=["pystache"],
    requires=[],
    python_requires=">=3",
    license="MIT",
)
